@@ -22,6 +22,7 @@ class GegevensGroepType:
         self,
         mapping: Dict[str, models.Field],
         optional: tuple = None,
+        required=None,
         none_for_empty=False,
     ):
         self.mapping = mapping
@@ -34,7 +35,11 @@ class GegevensGroepType:
         ), "The fields in 'optional' must be a subset of the mapping keys"
 
         # check if it's optional or not
-        self.required = any(field.blank is False for field in self.mapping.values())
+        self.required = (
+            required
+            if required is not None
+            else any(field.blank is False for field in self.mapping.values())
+        )
 
     def __repr__(self):
         fields = ", ".join(
@@ -71,20 +76,25 @@ class GegevensGroepType:
             if self.required:
                 raise ValueError("A non-empty value is required")
 
-            for field in self.mapping.values():
-                empty_value = None if field.null else ""
-                default_value = (
-                    field.default
-                    if field.default != models.NOT_PROVIDED
-                    else empty_value
-                )
+            for key, field in self.mapping.items():
+                default_value = self.get_default(key)
                 setattr(obj, field.name, default_value)
             return
 
         # map the values
         for key, field in self.mapping.items():
-            setattr(obj, field.name, value[key])
+            default_value = self.get_default(key)
+            new_value = value.get(key, default_value)
+            setattr(obj, field.name, new_value)
 
             if key not in self.optional:
                 attr_value = getattr(obj, field.name, None)
                 assert attr_value is not None, f"Empty '{key}' not allowed"
+
+    def get_default(self, prop: str):
+        field = self.mapping[prop]
+        empty_value = None if field.null else ""
+        default_value = (
+            field.default if field.default != models.NOT_PROVIDED else empty_value
+        )
+        return default_value
